# Diagram Library for JavaScript and TypeScript

A diagram library that enables you to build any type of graph, flowchart, tree, org chart, diagram, process chart, database schema and much more. Includes a huge variety of prdefined node and link shapes, automatic layout algorithms, many import and export options.

## Installing

For the latest stable version:

```
npm install diagram-library


```

### JS Diagram 3.4.4

- strokeThickness property added to Shape
- Bug fixes


### JS Diagram 3.4.2

- ExpandButtonAction enum and ExpandButtonAction property of Diagram
- ExpandButtonClicked event
- CompositeNode with shape outline shadows fixed
- Fixed IE browser crash


### JS Diagram 3.4.1

Provides support for additional controls in the [Angular](https://www.npmjs.com/package/diagram-library-angular), [React](https://www.npmjs.com/package/diagram-library-react) and [Vue](https://www.npmjs.com/package/diagram-library-vue) versions of MindFusion Diagramming.

### JS Diagram 3.4

#### React support

The DiagramView React component allows integrating the MindFusion.Diagramming API into React applications. It renders a [Diagram](https://www.mindfusion.eu/onlinehelp/jsdiagram/index.htm?CC_T_MindFusion_Diagramming_Diagram_0.htm) instance assigned to "diagram" prop as its model. Most diagram properties can be set from JSX, and all diagram events can be handled through JSX syntax as well. For more information, see the [Integration with React](https://www.mindfusion.eu/onlinehelp/jsdiagram/index.htm?React.htm) topic. 

[The DiagramView component for Rect on npm.](https://www.npmjs.com/package/diagram-library-react)

#### Vue.js support

The diagram-view Vue.js component allows integrating the MindFusion.Diagramming API into Vue.js applications. It renders a [Diagram](https://www.mindfusion.eu/onlinehelp/jsdiagram/index.htm?CC_T_MindFusion_Diagramming_Diagram_0.htm) instance assigned to "diagram" prop as its model. Most diagram properties can be set from the vue template, and all diagram events can be handled through the v-on directive as well. For more information, see the [Integration with Vue.js topic.](https://www.mindfusion.eu/onlinehelp/jsdiagram/index.htm?Vue_js.htm)

[The DiagramView component for Vue on npm.](https://www.npmjs.com/package/diagram-library-vue)

#### Angular support

The diagram-view Angular component allows integrating the MindFusion.Diagramming API into Angular applications. It renders a [Diagram](https://www.mindfusion.eu/onlinehelp/jsdiagram/index.htm?CC_T_MindFusion_Diagramming_Diagram_0.htm) instance assigned to "diagram" property as its model. Most diagram properties can be set from the html template, and all diagram events can be handled through event binding syntax as well. For more information, see the [Integration with Angular topic.](https://www.mindfusion.eu/onlinehelp/jsdiagram/index.htm?Angular.htm)

[The DiagramView component for Angular on npm.](https://www.npmjs.com/package/diagram-library-angular)


#### Video nodes

[VideoNode](https://www.mindfusion.eu/onlinehelp/jsdiagram/index.htm?T_MindFusion_Diagramming_VideoNode.htm) objects display video streams, along with UI elements to play, pause, seek and change volume. Call node's [setVideoLocation](https://www.mindfusion.eu/onlinehelp/jsdiagram/index.htm?M_MindFusion_Diagramming_VideoNode_setVideoLocation_1_String.htm) method to specify its video URL. Auto-playing is not supported at this time, and the video can be started only by users clicking the play button. VideoNode is built around [Video](https://www.mindfusion.eu/onlinehelp/jsdiagram/index.htm?T_MindFusion_Drawing_Video.htm) component, which can also be used in CompositeNode templates.

#### Miscellaneous

 - Improved automatic routing of links.
 - More precise scrolling with [TableNode](https://www.mindfusion.eu/onlinehelp/jsdiagram/index.htm?CC_T_MindFusion_Diagramming_TableNode_0.htm) scrollbar thumb.


### JS Diagram 3.3.10

Provides support for the Angular version of MindFusion Diagramming.

### JS Diagram 3.3.9

Provides support for the React version of MindFusion Diagramming. Details at [https://www.npmjs.com/package/diagram-library-react](https://www.npmjs.com/package/diagram-library-react)

### JS Diagram 3.3.8

Fixes for strict mode compatibility.

### JS Diagram 3.3.7

## Shape components

The [Shape](https://www.mindfusion.eu/onlinehelp/jsdiagram/index.htm?CC_T_MindFusion_Diagramming_Shape_0.htm) class used to specify [ShapeNode](https://www.mindfusion.eu/onlinehelp/jsdiagram/index.htm?CC_T_MindFusion_Diagramming_ShapeNode_0.htm) geometry can also be used as a component. When its isOutline attribute is set, the shape will control [CompositeNode]()'s geometry too, defining hit test and clip area, and link alignment points along node's border. If isOutline is disabled, the shape will serve mostly as a decorative element. The code below shows a sample fragment specifying shape component in template:

```
{
    component: "Shape",
    id: "Cloud",
    autoProperty: true,
    name: "OutlineShape",
    pen: "gray",
    brush: "Transparent",
    isOutline: true
}
```
## Miscellaneous

- [containerChildAdding](https://www.mindfusion.eu/onlinehelp/jsdiagram/index.htm?F_MindFusion_Diagramming_Events_containerChildAdding.htm) event handlers can stop propagation of the event up in the container hierarchy by calling [setHandled](https://www.mindfusion.eu/onlinehelp/jsdiagram/index.htm?M_MindFusion_Diagramming_ItemEventArgs_setHandled_1_Boolean.htm).
- [TableNode.resizeToFitText](https://www.mindfusion.eu/onlinehelp/jsdiagram/index.htm?M_MindFusion_Diagramming_TableNode_resizeToFitText_2_Boolean_Boolean_1.htm) improvements and fixes.
- [LayeredLayout](https://www.mindfusion.eu/onlinehelp/jsdiagram/index.htm?T_MindFusion_Graphs_LayeredLayout.htm) now uses stable sorting and should always create same results when applied to same graph.

### JS Diagram 3.3.6

This is a maintenance release containing fixes for recently reported problems:

* Fixed handling of transparent BackBrush in new drawing system.
* Fixed several drawing glitches.
* Fix for initializeNode and initializeLink events not firing.
* Updated Typescript definitions.

## New Features in JS Diagram 3.3.5

### Updated TypeScript Definitions

## New Features in JS Diagram 3.3.4

### Improved Performance 
Diagram rendering and user interactions are now faster. The control redraws the smallest possible area after diagram changes, and compresses refresh operations into a single batch when possible. Custom node classes that need to draw outside of their [Bounds](https://www.mindfusion.eu/onlinehelp/jsdiagram/index.htm?M_MindFusion_Diagramming_DiagramNode_getBounds_0.htm) should override the [getRepaintBounds](https://www.mindfusion.eu/onlinehelp/jsdiagram/index.htm?M_MindFusion_Diagramming_DiagramItem_getRepaintBounds_0.htm) method to specify the repaint area.

### Miscellaneous
* The [Border](https://www.mindfusion.eu/onlinehelp/jsdiagram/index.htm?T_MindFusion_Diagramming_Border.htm) component draws frame lines around and background behind other components in [CompositeNode](https://www.mindfusion.eu/onlinehelp/jsdiagram/index.htm?T_MindFusion_Diagramming_CompositeNode_0.htm) templates.
* [NodeListView](https://www.mindfusion.eu/onlinehelp/jsdiagram/index.htm?T_MindFusion_Diagramming_NodeListView.htm) now displays nodes' [Tooltip](https://www.mindfusion.eu/onlinehelp/jsdiagram/index.htm?M_MindFusion_Diagramming_DiagramItem_setTooltip_1_String.htm) texts when the mouse hovers over an item in the list view.
* Fix for [FlowchartLayout](https://www.mindfusion.eu/onlinehelp/jsdiagram/index.htm?T_MindFusion_Graphs_FlowchartLayout.htm) creating node overlaps in some situations.
   

## Documentation

1. [Detailed API Reference](https://www.mindfusion.eu/onlinehelp/jsdiagram/index.htm)
2. [Tutorials and Step-by-step Guides](https://www.mindfusion.eu/onlinehelp/jsdiagram/index.htm?CC_Tutorial_1__Loading_Graph_Data_1.htm)


## Samples

A variety of online samples are uploaded at the [MindFusion Js Diagram website.](https://mindfusion.eu/products/javascript/diagramming/samples) You can also visit the [online demo for Js Diagram.](https://mindfusion.co/demos/?sample=102) You can download an archive with all samples and all files for the library [from here.](http://mindfusion.eu/JsDiagramTrial.zip)


## Additional Information

Learn more about JS Diagram [from the official product page.](https://mindfusion.eu/javascript-diagram.html) Stay in touch with MindFusion about our latest product announcements, tutorials and programming guidelines via  [Twitter](https://twitter.com/MindFusion_News) or [our company blog.](https://mindfusion.eu/blog/)



## Technical Support

* [Forum](https://mindfusion.eu/Forum/YaBB.pl?board=jsdiag_disc)
* [E-mail](mailto:support@mindfusion.eu)
* [Help desk](https://www.mindfusion.eu/HelpDesk/index.php)

## Licensing

The end-user license agreement for JS Diagram is [here.](https://mindfusion.eu/eula.html)


